# Glossary

A glossary of common terms used in the InvenioRDM GitHub Archiver.

```{glossary}
API
    API stands for _application programming interface_. An API is an
    interface through which interactions between software can take place. It
    is an approach for software systems to communicate with each other.

CFF
    CFF stands for _Citation File Format_, the format of `CITATION.cff` files.
    The Citation File Format lets you provide citation metadata for software
    or datasets in plaintext files that are easy to read by both humans and
    machines.

CodeMeta
    The [CodeMeta Project](https://codemeta.github.io) defines metadata for
    describing software projects. CodeMeta defines crosswalks between the
    metadata properties stored in different resources and formats, and also
    defines a file format (`codemeta.json`) to store metadata property values
    for a given software project.
    
`codemeta.json`
    A file in [JSON-LD](https://json-ld.org) format that stores metadata
    property values for a given software project. The metadata fields in
    the file are defined by the [CodeMeta
    Project](https://codemeta.github.io)
    and built on and extend software properties from
    [Schema.org](https://schema.org). 

DOI
    DOI stands for _Digital Object Identifier_. A DOI is a [persistent
    identifier](https://en.wikipedia.org/wiki/Persistent_identifier) used
    to identify objects uniquely. The DOI format is standardized by the
    [International Organization for Standardization](https://www.iso.org)
    (ISO).

GitHub Action
    A GitHub Action is a workflow executed on GitHub to perform actions that
    can perform a wide range of possible actions. GitHub Actions are defined
    in files that use YAML syntax and a vocabulary
    [defined by GitHub](https://github.com/features/actions).

IGA
    IGA stands for _InvenioRDM GitHub Archiver_, a standalone program as well
    as a [GitHub Action](https://docs.github.com/en/actions) that automates
    the archiving of [GitHub](https://github.com) software releases in an
    [InvenioRDM](https://inveniosoftware.org/products/rdm/) repository.

Invenio
    Invenio is a free, open-source software framework for creating digital
    repositories. It provides tools for management of digital assets in
    an institutional repository.

InvenioRDM
    [InvenioRDM](https://inveniordm.docs.cern.ch) is a turn-key
    [research data management](https://riojournal.com/article/56508/) (RDM)
    platform that can be used by institutions to create repositories where
    data and software can be stored in order ensure long-term access to
    research products.

JSON
    JSON stands for _JavaScript Object Notation_. An open-standard format for
    storing data. The format uses a textual notation that is more or less
    human readable. It can be used to store lists, texts, numbers,
    attribute-value pairs, and more.

ORCID
    ORCID stands for _Open Researcher and Contributor ID_. ORCID is a
    not-for-profit organization that maintains the database and services
    associated with ORCID identifiers. ORCID id's are persistent, unique
    identifiers for researchers that help disambiguate people and associate
    publications with the correct individuals.

PAT
    PAT stands for _personal access token_. A PAT is string of characters
    used to authenticate a user when accessing a network service; it is a
    alternative to authentication via account+password combinations. PATs
    are used by both GitHub and InvenioRDM.

RDM
    RDM stands for _research data management_. Depending on context, it may
    be used to refer to the general concept of RDM or as a nickname for
    InvenioRDM.

ROR
    ROR stands for the _Research Organization Registry_. As of the
    year 2023, ROR includes identifiers and metadata for over 100,000
    organizations. Data is licensed according to the Creative Commons
    [CC0](https://creativecommons.org/share-your-work/public-domain/cc0/)
    license and available via API and other methods.

YAML
    YAML stands for _YAML Ain't Markup Language_. YAML is meant to be a
    "human-friendly data serialization language". It is typically stored 
    in plain-text files that can be edited in just about any text editor.

```
